@@ -19,6 +19,7 @@ import aiohttp.web as aiohttp_web
 
 # 4MB is the default inside aiohttp
 MAX_MSG_SIZE = int(os.environ.get("WSLINK_MAX_MSG_SIZE", 4194304))
+HEART_BEAT = int(os.environ.get("WSLINK_HEART_BEAT", 30)) # 30 seconds
 
 
 async def _on_startup(app):
@@ -37,7 +38,9 @@ def _schedule_shutdown(app):
 
 
 async def _root_handler(request):
-    return aiohttp.web.HTTPFound("/index.html")
+    if request.query_string:
+        return aiohttp.web.HTTPFound(f"index.html?{request.query_string}")
+    return aiohttp.web.HTTPFound("index.html")
 
 
 async def _stop_server(app):
@@ -141,7 +144,7 @@ def create_webserver(server_config):
             server_path = static_routes[route]
             routes.append(aiohttp_web.static(_fix_path(route), server_path))
 
-        # Resolve / => /index.html
+        # Resolve / => index.html
         web_app.router.add_route("GET", "/", _root_handler)
         web_app.add_routes(routes)
 
@@ -217,7 +220,7 @@ class WslinkHandler(object):
         aiohttp_app = request.app
 
         client_id = str(uuid.uuid4()).replace("-", "")
-        current_ws = aiohttp_web.WebSocketResponse(max_msg_size=MAX_MSG_SIZE, heartbeat=30)
+        current_ws = aiohttp_web.WebSocketResponse(max_msg_size=MAX_MSG_SIZE, heartbeat=HEART_BEAT)
         self.connections[client_id] = current_ws
 
         logging.info("client {0} connected".format(client_id))
@@ -380,7 +383,9 @@ class WslinkHandler(object):
             args.insert(0, obj)
 
             try:
-                results = await asyncio.coroutine(func)(*args, **kwargs)
+                results = func(*args, **kwargs)
+                if inspect.isawaitable(results):
+                    results = await results
                 await self.sendWrappedMessage(
                     rpcid, results, method=methodName, client_id=client_id
                 )
